@@ -30,9 +30,10 @@ class CompanyFilingModel(Base):
         ForeignKey('files.id'),
         nullable=False,
     )
-    type = Column(String(255), nullable=False)
+    type = Column(String(255), nullable=True)
     orig_file_url = Column(String(255), nullable=True)
     is_deleted = Column(Boolean, nullable=True)
+    unprocessed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
