@@ -14,9 +14,10 @@ class CompanyFilingResourceSchema(Schema):
     company_sec_id = fields.Integer(allow_none=True)
     company_ous_id = fields.Integer(allow_none=True)
     file_id = fields.Integer(required=True)
-    type = fields.String(required=True)
+    type = fields.String(allow_none=True)
     orig_file_url = fields.String(allow_none=True)
     is_deleted = fields.Boolean(allow_none=True)
+    unprocessed = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
