@@ -5,7 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
-    UniqueConstraint,
+    String,
     Boolean,
 )
 
@@ -30,6 +30,14 @@ class InterventionConditionModel(Base):
         Integer,
         nullable=True,
     )
+    geography = Column(
+        String(50),
+        nullable=True
+    )
+    line = Column(
+        Integer,
+        nullable=True
+    )
     is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
@@ -38,5 +46,3 @@ class InterventionConditionModel(Base):
         default=lambda: datetime.utcnow(),
         onupdate=lambda: datetime.utcnow(),
     )
-
-    __table_args__ = (UniqueConstraint("intervention_id", "condition_id"),)
