@@ -14,5 +14,6 @@ class SRCIdInterventionResourceSchema(Schema):
     intervention_id = fields.Integer(required=True)
     narrow = fields.Boolean(required=True)
     group = fields.Integer(required=True)
-    fields.Boolean(allow_none=True)
+    score = fields.Integer(allow_none=True)
+    final_mapping = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
